@@ -17,12 +17,18 @@ func (c *Client) Discovery() (string, error) {
 	return c.RawInformationQuery(c.jid, c.domain, reqID, IQTypeGet, XMPPNS_DISCO_ITEMS, "")
 }
 
-// Discover information about a node
+// Discover information about a node. Empty node queries info about server itself.
 func (c *Client) DiscoverNodeInfo(node string) (string, error) {
 	query := fmt.Sprintf("<query xmlns='%s' node='%s'/>", XMPPNS_DISCO_INFO, node)
 	return c.RawInformation(c.jid, c.domain, "info3", IQTypeGet, query)
 }
 
+// Discover information about given item from given jid.
+func (c *Client) DiscoverInfo(to string) (string, error) {
+	query := fmt.Sprintf("<query xmlns='%s'/>", XMPPNS_DISCO_INFO)
+	return c.RawInformation(c.jid, to, "info3", IQTypeGet, query)
+}
+
 // Discover items that the server exposes
 func (c *Client) DiscoverServerItems() (string, error) {
 	return c.DiscoverEntityItems(c.domain)
